﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using PTMedicalInsurance.Common;
using PTMedicalInsurance.Business;
using System.Windows.Forms;
using PTMedicalInsurance.Helper;
using Newtonsoft.Json.Linq;
using PTMedicalInsurance.Variables;
using PTMedicalInsurance.Forms;
using System.IO;
using System.Reflection;
using System.Data;
using PTMedicalInsurance.Business.Core.SelfServiceMachine.ProcessScheduler;
using PTMedicalInsurance.Business.Core.Forms.DischargeAudit;

namespace PTMedicalInsurance
{

    public class InsuBusiness : IInsuBusiness
    {
        //定义相关的变量
        private Patients patient;
        private Fees fee;
        private Settlements settlement;

        //json对象属性
        private JObject joInParam;
        private JArray jaSession;
        private JArray jaParams;
        private JObject joParam;
        private JObject joInterface;
        private JObject joInsuAdmObj;

        //设置业务实例
        CenterBusiness cBus = new CenterBusiness();
        HisMainBusiness hBus = new HisMainBusiness();
        HisIrisServices hIS = new HisIrisServices();
        MIIrisServices mIS= new MIIrisServices();
        InvokeHelper invoker = new InvokeHelper();
        
        private string businessType;
        private string operationType;

        public InsuBusiness()
        {
            Global.curEvt.path = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
            ComputerInfo comp = new ComputerInfo();
            Global.curEvt.mac = comp.GetMAC();
            Global.curEvt.ip = comp.GetIP(); //"10.1.4.100";  
            Global.pat.insuplc_admdvs = "";        //如果是NULL中心会报错
        }

        private int parseInparam(string inParam,out string errMsg)
        {
            errMsg = "";
            try
            {
                joInParam = JObject.Parse(inParam);
                jaSession = JArray.Parse(JsonHelper.getDestValue(joInParam, "session"));
                Global.curEvt.jaSession = jaSession;
                jaParams = JArray.Parse(JsonHelper.getDestValue(joInParam, "params"));
                joParam = JObject.FromObject(jaParams[0]);

                if (JsonHelper.getDestValue(joInParam, "insuAdmObj") != "")
                    joInsuAdmObj = JObject.Parse(JsonHelper.getDestValue(joInParam, "insuAdmObj"));

                joInterface = JObject.Parse(JsonHelper.getDestValue(joInParam, "interfaceinfo"));

                businessType = JsonHelper.getDestValue(joInParam, "businessType");
                operationType = JsonHelper.getDestValue(joInParam, "operationType");
                if ((businessType == "M6") || (businessType == "M6C") || (businessType == "M6Confirm"))
                {
                    Environment.CurrentDirectory = @"D:\HttpServerAPI\bin\libs";
                }

                return 0;
            }
            catch (Exception ex)
            {
                errMsg = "parseInparam 解析入参异常：" + errMsg;
                return -1;
            }
        }
        
        /// <summary>
        /// 签到
        /// </summary>
        /// <param name="InParam"></param>
        /// <returns></returns>
        public string Init(string InParam)
        {
            string errMsg, rtnResult ="";
            JObject joRtn = new JObject();
            try
            {
                if (hBus.initEnvironment(InParam, out errMsg) != 0)
                {   
                    return JsonHelper.setExceptionJson(-100, "initEnvironment 失败", errMsg).ToString();
                }
                else
                {
                    if (businessType == "DischargeAudit")
                    {
                        rtnResult = JsonHelper.setIrisReturnValue(0, "无需签到", joRtn).ToString();
                        return rtnResult;
                    }
                    
                    if (mIS.isSigned(ref Global.curEvt.signno) != true)
                    {
                        //签到
                        if (cBus.signIn(out joRtn) != 0)
                        {
                            rtnResult = JsonHelper.setExceptionJson(-1, "签到异常", (string)joRtn["err_msg"]).ToString();
                            return rtnResult;
                        }
                        else
                        {
                            Global.curEvt.signno = JsonHelper.getDestValue(joRtn, "output.signinoutb.sign_no");

                            //插入签到表
                            if (mIS.saveSignRecord(Global.curEvt.signno, out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setIrisReturnValue(0, "中心签到成功但插入签到表失败:" + errMsg, null).ToString();
                            }
                            else
                            {
                                rtnResult = JsonHelper.setIrisReturnValue(0, "签到成功", joRtn).ToString();
                            }
                        }
                    }
                    else
                    {
                        rtnResult = JsonHelper.setIrisReturnValue(0, "初始化成功！", null).ToString();
                    }

                    return rtnResult;
                }
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setExceptionJson(-100, "Init 异常", ex.Message).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("初始化结果：" + rtnResult);
            }
        }

        /// <summary>
        /// 初始化
        /// </summary>
        /// <param name="inParam"></param>
        /// <param name="outParam"></param>
        /// <returns></returns>
        private int init(string inParam, out string outParam)
        {
            string errMsg;
            outParam = "";
            try
            {
                //BS架构调用方式问题，每次调用都需要重新初始化
                JObject joInitRtn = JObject.Parse(Init(inParam));
                if (JsonHelper.parseIrisRtnValue(joInitRtn, out errMsg) != 0)
                {
                    outParam = JsonHelper.setExceptionJson(-100, "init(HIS医保环境初始化)", errMsg).ToString();
                    return -1;
                }
                else
                {
                    return 0;
                }
            }
            catch (Exception ex)
            {
                outParam = JsonHelper.setExceptionJson(-100, "init(HIS医保环境初始化)异常", ex.Message).ToString();
                return -1;
            }
        }

        /// <summary>
        /// 获取患者信息
        /// </summary>
        /// <param name="InParam"></param>
        /// <returns></returns>
        public string GetPatientInfo(string InParam)
        {
            Global.writeLog("GetPatientInfo入参:" + JsonHelper.Compress(InParam));
            //设置返回值，错误信息
            int errCode;
            string errMsg, rtnResult = "",outParam;
            //BS架构调用方式问题，每次调用都需要重新初始化
            if (init(InParam,out outParam)!= 0)
            {
                rtnResult = outParam;
                return rtnResult;
            }
            JObject joInParam = JObject.Parse(InParam);
            string businessType = JsonHelper.getDestValue(joInParam,"businessType");

            try
            {
                switch (businessType)
                {
                    case "M1"://门诊读卡
                        {
                            //打开读卡窗口，操作员选择读卡类型后进行读卡器读卡，再进行1101获取参保信息
                            if (hBus.readCard(out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "门诊读卡失败！", outParam).ToString();
                            }
                            else
                            {
                                //展示患者信息界面
                                if (hBus.showPatInfo(outParam, out outParam) != 0)
                                {
                                    rtnResult = outParam;                                    
                                }
                                else
                                {
                                    rtnResult = JsonHelper.setIrisReturnValue(0, "", JObject.Parse(outParam)).ToString();
                                }
                            }

                            break;
                        }
                    case "Z1"://住院读卡
                        {
                            //打开读卡窗口，操作员选择读卡类型后进行读卡器读卡，再进行1101获取参保信息
                            if (hBus.readCard(out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "住院读卡失败！", outParam).ToString();
                            }
                            else
                            {
                                string patInfo = outParam;
                                //展示患者信息界面
                                if (hBus.showPatInfo(patInfo, out outParam) != 0)
                                {
                                    rtnResult = outParam;
                                }
                                else
                                {                                    
                                    rtnResult = JsonHelper.setIrisReturnValue(0,"",JObject.Parse(outParam)).ToString();
                                }
                            }
                            break;
                        }     
                }
                return rtnResult;
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setIrisReturnValue(-1 , "GetPatientInfo发生异常;" + ex.Message,null).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("GetPatientInfo出参:" + JsonHelper.Compress(rtnResult));
            }            
        }

        /// <summary>
        /// 登记
        /// </summary>
        /// <param name="InParam"></param>
        /// <returns></returns>
        public string Register(string InParam)
        {            
            Global.writeLog("Register 入参:" + JsonHelper.Compress(InParam));
            //设置返回值，错误信息
            string errMsg, rtnResult = "", outParam;
            try
            {
                //解析入参
                if (parseInparam(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "", errMsg).ToString();
                    return rtnResult;
                }
                //BS架构调用方式问题，每次调用都需要重新初始化
                if (init(InParam, out outParam) != 0)
                {
                    rtnResult = outParam;
                    return rtnResult;
                }
                //获取pat
                hBus.GetRegPatInfo(businessType, joInParam, out Global.pat);
                switch (businessType)
                {
                    case "M2"://门诊登记
                        {

                            break;
                        }
                    case "M2C"://门诊登记撤销
                        {
                            break;
                        }
                    case "Z0"://住院修改
                        {

                            break;
                        }
                    case "Z2"://入院登记
                        {
                            Global.pat.RYorCY = "1"; //1入院2出院
                            string  regInParam = "";

                            //校验HIS姓名与医保姓名是否一致
                            if (hBus.checkName(Global.pat.name, out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "校验HIS与医保姓名是否一致", errMsg).ToString();
                                return rtnResult;
                            }


                            //显示登记面板
                            if (hBus.showInPatRegisterForm( out regInParam) == 0)
                            {
                                JObject joRegIn_plain = JObject.Parse(JsonHelper.setCenterInpar_plain("2401", regInParam));
                                JObject joRegIn = JObject.Parse(JsonHelper.setCenterInpar("2401", regInParam));
                                //上传给中心
                                JObject joRegOut = invoker.invokeCenterService("2401", joRegIn);
                                //将中心返回的结果返回HIS,调用HIS服务进行保存
                                if (JsonHelper.parseCenterRtnValue(joRegOut,out errMsg) == 0)
                                {
                                    joRegOut.Add("validflag",1);
                                    joRegOut.Add("regstate", 1);
                                    joRegOut.Add("type", 1);
                                    Global.pat.mdtrtID = JsonHelper.getDestValue(joRegOut, "output.result.mdtrt_id");
                                    //插入患者本次就诊用的参保信息
                                    if (hBus.insertPatCurInsuInfo(JsonHelper.getDestValue(joParam, "patientInfo"), out outParam) != 0)
                                    {
                                        if (DialogResult.Yes == MessageBox.Show(outParam, " 是否继续？ ", MessageBoxButtons.YesNo))
                                        {

                                        }
                                        else
                                        {
                                            rtnResult = JsonHelper.setExceptionJson(-1, "插入患者本次就诊用的参保信息，请联系管理员！", outParam).ToString();
                                            return rtnResult;
                                        }
                                    }
                                    
                                    //插入医保平台
                                    if (mIS.saveInpatRegisterInfo(joRegIn_plain, joRegOut, out outParam) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "云平台保存登记信息", outParam).ToString();
                                        return rtnResult;
                                    }

                                    JObject joOutput = new JObject();
                                    joOutput.Add("output", JObject.Parse(JsonHelper.getDestValue(joParam, "patientInfo.output")));
                                    //插入医保平台全量信息表
                                    if (mIS.saveMIPatFullInsuInfo(joOutput, out outParam) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "云平台保存登记全量信息失败", outParam).ToString();
                                        return rtnResult;
                                    }
                                    //插入费用核查表 入院登记
                                    if (mIS.saveDischargeAudit(3, 2,0, joRegIn, out outParam) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "云平台保存费用核查入院登记信息", outParam).ToString();
                                        return rtnResult;
                                    }

                                    //插入费用核查表 出院登记 默认，具体需要最终审核
                                    JObject joDisReg = (JObject)joRegIn.DeepClone();
                                    //joDisReg["input"]["mdtrtinfo"]["psn_setlway"] = new JObject();
                                    joDisReg["input"]["mdtrtinfo"]["psn_setlway"] = "01";
                                    //joDisReg["input"]["mdtrtinfo"]["acct_used_flag"] = new JObject();
                                    joDisReg["input"]["mdtrtinfo"]["acct_used_flag"] = "1";
                                    //joDisReg["input"]["mdtrtinfo"]["mid_setl_flag"] = new JObject();
                                    joDisReg["input"]["mdtrtinfo"]["mid_setl_flag"] = "0";
                                    if (mIS.saveDischargeAudit(3, 3,0,joDisReg, out outParam) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "云平台保存费用核查出院登记信息(默认)", outParam).ToString();
                                        return rtnResult;
                                    }
                                    //返回登记信息，插入HIS
                                    if (hIS.returnRegisterInfo(joRegIn_plain, joRegOut, out outParam) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "HIS平台保存登记信息", outParam).ToString();
                                        return rtnResult;
                                    }
                                    else
                                    {
                                        rtnResult = JsonHelper.setIrisReturnValue(0, "登记成功", null).ToString();
                                        return rtnResult;
                                    }
                                }
                                else
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "展示登记界面", errMsg).ToString();
                                    return rtnResult;
                                }
                            }
                            else
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "展示登记界面", regInParam).ToString();
                                return rtnResult;
                            }

                        }
                    case "Z2C"://入院登记取消
                        {
                            //if (DialogResult.Yes == MessageBox.Show("即将进行取消中心医保登记，确定继续吗？", " 询问？ ", MessageBoxButtons.YesNo))
                            //{

                            //}
                            //else
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "收费员撤销取消登记操作！", outParam).ToString();
                            //    return rtnResult;
                            //}

                            //取消中心登记
                            if (cBus.cancleRegister("2404", out outParam) != 0)
                            {
                                //如果医保中心没有HIS所传的医保登记信息则默认撤销HIS登记信息
                                int i = outParam.IndexOf("不存在有效的就诊登记信息");
                                if (i != 0)
                                {
                                    if (DialogResult.Yes != MessageBox.Show("医保中心提示：" + outParam+ "，是否强制撤销HIS医保登记信息？", "提示", MessageBoxButtons.YesNo))
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "中心取消登记失败，", outParam).ToString();
                                        return rtnResult;
                                    }
                                }
                                else
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "中心取消登记失败，", outParam).ToString();
                                    return rtnResult;
                                }
                            }

                            //取消医保平台登记
                            if (mIS.cancleRegister(1, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "中心取消登记成功，但云医保平台取消失败，", outParam).ToString();
                                return rtnResult;
                            }

                            ////取消费用审核
                            //if (mIS.cancleRegister(1, out outParam) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "中心取消登记成功，但云医保平台取消失败，", outParam).ToString();
                            //    return rtnResult;
                            //}
                            //取消HIS 登记
                            if (hIS.cancleRegister( out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "中心和云医保平台取消登记成功，但HIS取消失败，", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                //CM 20230602 删除医保平台医保费用明细上传表数据
                                mIS.deleteFee(out errMsg);
                                rtnResult = JsonHelper.setIrisReturnValue(0, "取消医保登记成功", null).ToString();
                                return rtnResult;
                            }
                        }
                    case "Z6"://出院登记
                        {



                            break;
                        }
                    case "Z6C"://出院登记取消
                        {

                            if (cBus.cancleRegister("2405", out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "取消出院登记", errMsg).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                rtnResult = JsonHelper.setIrisReturnValue(0, "取消出院登记成功", null).ToString();
                                return rtnResult;
                            }
                            break;
                        }
                    default:
                        {
                            rtnResult = JsonHelper.setExceptionJson(-1, "Register 交易", "传入的业务编码不对！").ToString();
                            return rtnResult;
                        }

                }
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setIrisReturnValue(-1, "Register 发生异常;" + ex.Message, null).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("Register 出参:" + JsonHelper.Compress(rtnResult));
            }


            return "";
        }

        /// <summary>
        /// 费用上传
        /// </summary>
        /// <param name="InParam"></param>
        /// <returns></returns>
        public string FeeUpload(string InParam)
        {
            Global.writeLog("FeeUpload 入参:" +  JsonHelper.Compress(InParam));
            //设置返回值，错误信息
            int errCode;
            string errMsg, rtnResult = "", outParam;
            try
            {
                //解析入参
                if (parseInparam(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "", errMsg).ToString();
                    return rtnResult;
                }
                
                //BS架构调用方式问题，每次调用都需要重新初始化
                if (init(InParam, out outParam) != 0)
                {
                    rtnResult = outParam;
                    return rtnResult;
                }
                //获取pat
                hBus.GetFeeHisInfo(businessType, joInParam, out Global.pat);
                switch (businessType)
                {


                    case "M3"://门诊费用上传
                        {
                            break;
                        }
                    case "M3C"://门诊费用撤销
                        {

                            break;
                        }
                    case "Z3"://入院费用上传
                        {
                            //从医保平台获取患者详细的医保登记信息
                            if (mIS.queryRegisterInfo(1, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "查询患者云平台登记信息", outParam).ToString();
                                return rtnResult;
                            }
                            JObject joReg = JObject.Parse(outParam);
                            Global.pat.medType = JsonHelper.getDestValue(joReg, "data.MedicalType");
                            Global.pat.insuType = JsonHelper.getDestValue(joReg, "data.InsuType");
                            //先取消中心费用传送
                            cBus.cancleFeeUpload("2302", out errMsg);
                            //再删除医保传送表的数据
                            mIS.deleteFee( out errMsg);

                            #region【住院费用上传前调用3101事前服务】
                            //1.获取3101入参报文           
                            if (hIS.GetInsuPatInfo("5", Global.pat, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "获取3101医保明细审核事前分析服务入参失败：", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                //2.调用医保3101明细审核事前分析服务
                                JObject joInput = new JObject();
                                joInput = JObject.Parse(outParam);
                                JObject jo3101Rtn = invoker.invokeCenterService("3101", JsonHelper.setCenterInpar("3101", joInput.ToString().Replace("\r\n", "")));
                                if (JsonHelper.parseCenterRtnValue(jo3101Rtn, out errMsg) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "【3101】医保明细审核事前分析服务调用失败：", errMsg).ToString();
                                    return rtnResult;
                                }
                                else
                                {
                                    JArray jaResult = JArray.Parse(JsonHelper.getDestValue(jo3101Rtn, "output.result"));
                                    if (jaResult.HasValues)
                                    {
                                        PreAndInProcessAnalysisForm paipaForm = new PreAndInProcessAnalysisForm(jo3101Rtn);
                                        if (paipaForm.ShowDialog() != DialogResult.OK)
                                        {
                                            errMsg = "事前事中审核不通过，操作员取消!";
                                            rtnResult = JsonHelper.setExceptionJson(-1, "【3101】医保明细审核事前分析服务调用失败：", errMsg).ToString();
                                            return rtnResult;
                                        }
                                    }
                                }
                            }
                            #endregion


                            //开始进行费用传送
                            //调用HIS费用查询信息
                            if (hIS.getHisFee(Global.pat, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "获取HIS费用", outParam).ToString();
                                return rtnResult;
                            }
                            //调用医保平台转换
                            JObject joHisFee = JObject.Parse(outParam);
                            if (mIS.convertHisFeeWithInsuCode(joHisFee,out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "转换HIS费用", outParam).ToString();
                                return rtnResult;
                            }

                            JArray jaFeeDetail = JArray.Parse(JsonHelper.getDestValue(JObject.Parse(outParam), "data"));
                            //按指定条数分割后上传，保存，更新
                            if (hBus.uploadFeeToCenter("2301",10, jaFeeDetail, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "上传费用", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                rtnResult = JsonHelper.setIrisReturnValue(0, "住院费用上传成功", null).ToString();
                                return rtnResult;
                            }
                        }
                    case "Z3C"://住院费用上传取消
                        {
                            if (cBus.cancleFeeUpload("2302", out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "取消中心费用", errMsg).ToString();
                                return rtnResult;
                            }

                            if (mIS.deleteFee( out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "删除医保平台费用", errMsg).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                rtnResult = JsonHelper.setIrisReturnValue(0, "住院费用上传取消成功", null).ToString();
                                return rtnResult;
                            }

                        }

                    default:
                        {
                            rtnResult = JsonHelper.setExceptionJson(-1, "FeeUpload 交易", "传入的业务编码不对！").ToString();
                            return rtnResult;
                        }
                }
                return rtnResult;
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setExceptionJson(-1, "FeeUpload 交易", ex.Message).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("FeeUpload 出参：" + JsonHelper.Compress(rtnResult));
            }
        }

        /// <summary>
        /// 结算
        /// </summary>
        /// <param name="InParam"></param>
        /// <returns></returns>
        public string Settlement(string InParam)
        {
            Global.writeLog("Settlement 入参：" + JsonHelper.Compress(InParam));
            //设置返回值，错误信息
            string errMsg, rtnResult = "", outParam;
            try
            {
                //解析入参
                if (parseInparam(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "", errMsg).ToString();
                    return rtnResult;
                }
                //BS架构调用方式问题，每次调用都需要重新初始化
                if (init(InParam, out outParam) != 0)
                {
                    rtnResult = outParam;
                    return rtnResult; 
                }
                //获取pat
                hBus.GetSettlementHisInfo(businessType, joInParam, out Global.pat);

                CardReader_GS CardRead_GS = new CardReader_GS();

                switch (businessType)
                {
                    case "M4"://门诊预结算
                        {
                            OutpatientRegistration frmReg = new OutpatientRegistration();
                            if (frmReg.ShowDialog() == DialogResult.OK)
                            {
                                rtnResult = "调用结束";
                            }

                            break;
                        }
                    case "M4C"://门诊预结算撤销
                        {
                            break;
                        }
                    case "M5"://门诊结算
                        {
                            Global.pat.admType = 1;
                            string patInfo ="";
                            //打开读卡窗口，操作员选择读卡类型后进行读卡器读卡，再进行1101获取参保信息
                            if (hBus.readCard(out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "读卡失败！", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                patInfo = outParam;
                                //展示患者信息界面
                                if (hBus.showPatInfo(patInfo, out outParam) != 0)
                                {
                                    rtnResult = outParam;
                                    return rtnResult;
                                }
                            }
                            //患者信息赋值给全局变量
                            patInfo = outParam;
                            
                            if (hBus.setGlobalPatAfaterShowPatInfo(patInfo, out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "setGlobalPatAfaterShowPatInfo", errMsg).ToString();
                                return rtnResult;
                            }
                            //校验HIS姓名与医保姓名是否一致
                            if (hBus.checkName(Global.pat.name, out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "校验HIS与医保姓名是否一致", errMsg).ToString();
                                return rtnResult;
                            }

                            //显示登记面板
                            if (hBus.showOutPatRegisterForm(out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "显示登记面板", outParam).ToString();
                                return rtnResult;
                            }
                            JObject joReg = JObject.Parse(outParam);

                            //医保挂号
                            JObject jo2201Inpar = JObject.Parse(JsonHelper.getDestProperty(joReg, "data"));
                            JObject jo2201Inpar_plain = JObject.Parse(JsonHelper.getDestProperty(joReg, "data"));
                            jo2201Inpar = JObject.Parse(JsonHelper.setCenterInpar("2201", jo2201Inpar));
                            jo2201Inpar_plain = JObject.Parse(JsonHelper.setCenterInpar_plain("2201", jo2201Inpar_plain)); 
                            //此处先取到就诊信息上传的入参，只要挂号成功就保存到云HIS后台（保存后台需要用到2203入参）
                            JObject jo2203Inpar = new JObject();
                            JObject jo2203Inpar_plain = new JObject();
                            jo2203Inpar.Add("mdtrtinfo", JObject.Parse(JsonHelper.getDestValue(joReg, "mdtrtinfo")));
                            jo2203Inpar.Add("diseinfo",JArray.Parse(JsonHelper.getDestValue(joReg, "diseinfo")));
                            JObject jo2201Rtn = invoker.invokeCenterService("2201", jo2201Inpar);
                            if (JsonHelper.parseCenterRtnValue(jo2201Rtn, out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "医保挂号", errMsg).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                Global.pat.mdtrtID = JsonHelper.getDestValue(jo2201Rtn, "output.data.mdtrt_id");
                                //插入患者本次就诊用的参保信息
                                if (hBus.insertPatCurInsuInfo(patInfo, out outParam) != 0)
                                {
                                    if (DialogResult.Yes != MessageBox.Show(outParam, " 是否继续？ ", MessageBoxButtons.YesNo))         
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "插入患者本次就诊用的参保信息，请联系管理员！是否继续？", outParam).ToString();
                                        return rtnResult;
                                    }
                                }
                                jo2203Inpar["mdtrtinfo"]["mdtrt_id"] = Global.pat.mdtrtID;
                                jo2203Inpar_plain = JObject.Parse(JsonHelper.setCenterInpar_plain("2203", jo2203Inpar));
                                jo2203Inpar = JObject.Parse(JsonHelper.setCenterInpar("2203", jo2203Inpar));
                                //门诊登记信息，插入云医保平台
                                jo2201Rtn.Add("validflag", 1);
                                jo2201Rtn.Add("regstate", 1);
                                jo2201Rtn.Add("type", 3);
                                Global.writeLog(jo2201Inpar_plain.ToString());
                                if (mIS.saveOutpatRegisterInfo(jo2201Inpar_plain, jo2201Rtn, jo2203Inpar_plain, out errMsg) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "中心登记成功但医保平台保存失败，请联系管理员！", errMsg).ToString();
                                    return rtnResult;
                                }
                            }

                            //门诊就诊信息上传                            
                            JObject jo2203Rtn = invoker.invokeCenterService("2203",jo2203Inpar );
                            if (JsonHelper.parseCenterRtnValue(jo2203Rtn, out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "门诊就诊信息上传", errMsg).ToString();
                                return rtnResult;
                            }

                            #region【门诊就诊信息上传成功后调用3101事前服务】                            
                            //1.获取3101入参报文
                            if (Global.curEvt.ext.isOpenAnalysis)
                            {
                                if (hIS.GetInsuPatInfo("1", Global.pat, out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "获取3101医保明细审核事前分析服务入参失败：", outParam).ToString();
                                    return rtnResult;
                                }
                                else
                                {
                                    //2.调用医保3101明细审核事前分析服务
                                    JObject joInput = new JObject();
                                    //joInput.Add("data", JObject.Parse(outParam));
                                    joInput = JObject.Parse(outParam);

                                    JObject jo3101Rtn = invoker.invokeCenterService("3101", JsonHelper.setCenterInpar("3101", joInput.ToString().Replace("\r\n", ""))); //.Replace(" ", "")
                                    if (JsonHelper.parseCenterRtnValue(jo3101Rtn, out errMsg) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "【3101】医保明细审核事前分析服务调用失败：", errMsg).ToString();
                                        return rtnResult;
                                    }
                                    else
                                    {
                                        JArray jaResult = JArray.Parse(JsonHelper.getDestValue(jo3101Rtn, "output.result"));
                                        if (jaResult.HasValues)
                                        {
                                            PreAndInProcessAnalysisForm paipaForm = new PreAndInProcessAnalysisForm(jo3101Rtn);
                                            if (paipaForm.ShowDialog() != DialogResult.OK)
                                            {
                                                errMsg = "事前事中审核不通过，操作员取消!";
                                                rtnResult = JsonHelper.setExceptionJson(-1, "【3101】医保明细审核事前分析服务调用失败：", errMsg).ToString();
                                                return rtnResult;
                                            }
                                        }
                                    }
                                }
                            }
                               
                            #endregion

                            //费用上传
                            if (hBus.uploadFee("2204", 50, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "费用上传", outParam).ToString();
                                return rtnResult;
                            }

                            #region【门诊预结算2206前调用3102医保明细审核事中服务】     

                            if (Global.curEvt.ext.isOpenAnalysis)
                            {
                                //1.获取3102入参报文
                                if (hIS.GetInsuPatInfo("2", Global.pat, out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "获取3102医保明细审核事中分析服务入参失败：", outParam).ToString();
                                    return rtnResult;
                                }
                                else
                                {
                                    //2.调用医保3102明细审核事前分析服务
                                    JObject joInput = new JObject();
                                    //joInput.Add("data", JObject.Parse(outParam));
                                    joInput = JObject.Parse(outParam);

                                    JObject jo3102Rtn = invoker.invokeCenterService("3102", JsonHelper.setCenterInpar("3102", joInput.ToString().Replace("\r\n", "")));
                                    if (JsonHelper.parseCenterRtnValue(jo3102Rtn, out errMsg) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "【3102】医保明细审核事中分析服务调用失败：", errMsg).ToString();
                                        return rtnResult;
                                    }
                                    else
                                    {
                                        JArray jaResult = JArray.Parse(JsonHelper.getDestValue(jo3102Rtn, "output.result"));
                                        if (jaResult.HasValues)
                                        {
                                            PreAndInProcessAnalysisForm paipaForm = new PreAndInProcessAnalysisForm(jo3102Rtn);
                                            if (paipaForm.ShowDialog() != DialogResult.OK)
                                            {
                                                errMsg = "事前事中审核不通过，操作员取消!";
                                                rtnResult = JsonHelper.setExceptionJson(-1, "【3102】医保明细审核事中分析服务调用失败：", errMsg).ToString();
                                                return rtnResult;
                                            }
                                        }
                                    }
                                }
                            }
                             
                            #endregion

                            //调用IRIS获取医保各项金额
                            if (mIS.getSumFee(out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "获取医保费用各项汇总金额", outParam).ToString();
                                return rtnResult;
                            }
                            JObject joSumFee = JObject.Parse(outParam);
                            JObject joSettlement = JObject.Parse(JsonHelper.getDestValue(joReg, "settlement"));
                            //修改joSettlement的就诊ID ,总金额等
                            joSettlement["mdtrt_id"] = Global.pat.mdtrtID;
                            joSettlement["medfee_sumamt"] = JsonHelper.getDestValue(joSumFee, "data.Sumamt");       

                            //预结算2206
                            if (hBus.preSettlement_OutPat(joSettlement, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "结算信息展示", outParam).ToString();
                                return rtnResult;
                            }

                            #region【门诊正式结算前调用社保卡验密】
                            if ((Global.pat.mdtrtcertType == "03") && (Global.pat.insuplc_admdvs.Substring(0, 2) == "62"))
                            {
                                if (CardRead_GS.VerifyPIN(out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "社保卡验密异常iVerifyPIN失败 ", outParam).ToString();
                                    return rtnResult;
                                }
                            }
                            #endregion

                            //正式结算
                            JObject joData = new JObject();
                            joData.Add("data",joSettlement);
                            JObject joRtn = invoker.invokeCenterService("2207", JsonHelper.setCenterInpar("2207", joData));
                            if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "结算失败", errMsg).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                //返回给云医保平台结算信息
                                if (mIS.saveSettlement(joRtn, out errMsg) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "结算成功，但云医保平台保存失败", errMsg).ToString();
                                    return rtnResult;
                                }
                                //返回给云医保平台结算明细信息
                                if (mIS.saveSettlementDetail(joRtn, out errMsg) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "云医保平台保存结算明细失败", errMsg).ToString();

                                    return rtnResult;
                                }
                                
                               //返回给HIS
                               JObject joSetlinfo = JObject.Parse(JsonHelper.getDestValue(joRtn, "output.setlinfo"));
                                if (hIS.returnOutpatSettlementInfo(joSettlement, joSetlinfo, out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "返回结算信息给HIS", outParam).ToString();
                                    return rtnResult;
                                }
                                else
                                {
                                    JObject joHisServieRtn = JObject.Parse(outParam);
                                    hBus.returnToFrontEndAfterSettlement(joRtn, joHisServieRtn, out outParam);
                                    rtnResult = JsonHelper.setIrisReturnValue(0, "结算成功", JObject.Parse(outParam)).ToString();
                                    return rtnResult;
                                }
                            }
                        }
                    case "M5C"://门诊结算撤销
                        {
                            //查询HIS医保结算记录表获取该病人的参保地
                            string sqlStr = "SELECT * FROM  BS_MedInsuSettlement WHERE billType = 1 and ValidFlag = 1 ";
                            sqlStr = sqlStr + " AND Hospital_Dr=" + Global.inf.hospitalDr + " AND Interface_Dr=" + Global.inf.interfaceDr;
                            sqlStr = sqlStr + " AND SettlementID ='" + Global.pat.settlID + "'";

                            JObject joSql = new JObject();
                            joSql.Add("sqlStr", sqlStr);
                            JObject joSettlInfo = mIS.QuerySettlementInfo(joSql);
                            //if (JsonHelper.parseIrisRtnValue(joSettlInfo, out errMsg) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "查询结算信息失败！", errMsg).ToString();
                            //    return rtnResult;
                            //}
                            Global.pat.insuplc_admdvs = JsonHelper.getDestValue(joSettlInfo, "result.data[0].insuplc_admdvs");

                            //退中心结算
                            string newSettleID = ""; 
                            if (cBus.cancleSettlement("2208", out outParam) != 0)
                            {
                                int i = outParam.IndexOf("获取到的就诊信息为无效状态，不能办理结算撤销业务");
                                if (i != 0)
                                {
                                    if (DialogResult.Yes != MessageBox.Show("医保中心提示：" + outParam + "，是否强制撤销HIS结算信息？", "提示", MessageBoxButtons.YesNo))
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "中心取消结算失败，", outParam).ToString();
                                        return rtnResult;
                                    }

                                    newSettleID = "YC";
                                }
                                else
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "取消中心结算", outParam).ToString();
                                    //查看是医保平台是否已经退费，如果是，则询问是否继续退费
                                    string SqlStr = " SELECT * FROM  BS_MedInsuSettlement WHERE  ValidFlag = 0 AND BillType = -1 ";
                                    SqlStr = SqlStr + " AND Hospital_Dr=" + Global.inf.hospitalDr + " AND Interface_Dr=" + Global.inf.interfaceDr;
                                    SqlStr = SqlStr + " AND SettlementID ='" + Global.pat.settlID + "'";

                                    JObject joSqlStr = new JObject();
                                    joSqlStr.Add("sqlStr", SqlStr);

                                    JObject joCancleSettlInfo = mIS.QuerySettlementInfo(joSqlStr);


                                    JArray jaCancleSettlInfo = JArray.Parse(JsonHelper.getDestValue(joCancleSettlInfo, "result.data"));
                                    if (jaCancleSettlInfo.Count == 1)
                                    {
                                        //询问收款员是否继续进行HIS退费
                                        if (DialogResult.Yes == MessageBox.Show("中心提示：" + outParam, " 该费用在医保中心已成功退费但在HIS未成功退费，是否强制退HIS费用？ ", MessageBoxButtons.YesNo))
                                        {
                                            rtnResult = JsonHelper.setExceptionJson(0, "该费用在医保中心已成功退费但在HIS未成功退费，收款员选择强制退HIS费用！", outParam).ToString();
                                        }
                                    }
                                    else
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "取消中心结算(云医保平台未退费或未查询到退费记录)", outParam).ToString();
                                    }

                                    return rtnResult;
                                }

                            }
                            else
                            {
                                newSettleID = JsonHelper.getDestValue(JObject.Parse(outParam), "output.setlinfo.setl_id");
                            }
                                         
                            //string newSettleID = "10290453";
                            //Global.pat.mdtrtID = "202210281547480034293700000000";
                            //Global.pat.psn_no = "YX423049577";
                            //Global.pat.settlID = "10290445";

                            //退云医保平台结算
                            if (mIS.cancleSettlement(newSettleID, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "取消平台结算信息", outParam).ToString();
                                //return rtnResult;
                            }
                            //中心取消传送
                            if (cBus.cancleFeeUpload("2205", out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "取消中心费用", errMsg).ToString();
                                return rtnResult;
                            }
                            //云平台取消传送
                            if (mIS.deleteFee(out errMsg) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "删除医保平台费用", errMsg).ToString();
                                return rtnResult;
                            }
                            //取消中心登记
                            if (cBus.cancleRegister("2202", out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "中心取消登记失败，", outParam).ToString();
                                return rtnResult;
                            }
                            //取消医保平台登记
                            if (mIS.cancleRegister(3, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "中心取消登记成功，但云医保平台取消失败，", outParam).ToString();
                                return rtnResult;
                            }
                            //退HIS结算
                            if (hIS.cancleSettlementInfo(joParam, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "取消HIS结算信息", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                rtnResult = JsonHelper.setIrisReturnValue(0, "取消结算成功", null).ToString();
                                return rtnResult;
                            }
                        }
                    case "M6"://门诊移动支付结算
                        {
                            MobilePay mp = new MobilePay(InParam, out errMsg);
                            if (errMsg != "")
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易1", errMsg).ToString();
                                return rtnResult;
                            }

                            if (mp.MobilePaySettlement(out outParam) != 0)
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易2", outParam).ToString();
                            else
                                rtnResult = outParam;

                            return rtnResult;
                        }
                    case "M6C"://门诊移动支付结算撤销
                        {
                            string onlineYBFalg = JsonHelper.getDestValue(joInsuAdmObj, "onlineYBFalg");

                            MobilePay mp = new MobilePay(InParam, out errMsg);
                            if (errMsg != "")
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易3", errMsg).ToString();
                                return rtnResult;
                            }

                            if (String.IsNullOrEmpty(onlineYBFalg))
                                mp.MSettl.onlineYBFalg = "N";
                            else
                                mp.MSettl.onlineYBFalg = onlineYBFalg;

                            if (mp.MobilePayCancelSettlement(out outParam) != 0)
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易4", outParam).ToString();
                            else
                                rtnResult = JsonHelper.setExceptionJson(0, "Settlement 交易5", outParam).ToString();

                            return rtnResult;
                        }
                    case "M6Confirm"://门诊移动支付确认
                        {
                            MobilePay mp = new MobilePay(InParam, out errMsg);
                            if (errMsg != "")
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易6", errMsg).ToString();
                                return rtnResult;
                            }                            

                            if (mp.MobilePayConfirmSettlement(out outParam) != 0)
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易7", outParam).ToString();
                            else
                                rtnResult = outParam;

                            return rtnResult;
                        }
                    case "M6CallBack"://门诊移动支付回调
                        {
                            JObject jo = JObject.Parse(InParam);
                            joInsuAdmObj = new JObject();
                            joInsuAdmObj.Add("payOrdId", "");
                            jo.Add("insuAdmObj", joInsuAdmObj);
                            MobilePay mp = new MobilePay(jo.ToString(), out errMsg);
                            if (errMsg != "")
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易8", errMsg).ToString();
                                return rtnResult;
                            }
                            if (mp.MobilePayCallbackSettlement(out outParam) != 0)
                                rtnResult = outParam;
                            else
                                rtnResult = outParam;
                            return rtnResult;
                        }

                    case "Z4"://住院预结算
                        {                            
                            #region【住院预结算2303前调用3102医保明细审核事中服务】                            
                            //1.获取3102入参报文
                            /*
                            if (hIS.GetInsuPatInfo("9", Global.pat, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "获取3102医保明细审核事中分析服务入参失败：", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                //2.调用医保3102明细审核事前分析服务
                                JObject joInput = new JObject();
                                joInput = JObject.Parse(outParam);
                                JObject jo3102Rtn = invoker.invokeCenterService("3102", JsonHelper.setCenterInpar("3102", joInput.ToString().Replace("\r\n", "")));
                                if (JsonHelper.parseCenterRtnValue(jo3102Rtn, out errMsg) != 0)
                                {
                                    DialogResult dr = MessageBox.Show("【3102】医保明细审核事中分析服务医保中心返回结果2：" + errMsg + "！是否继续？", "提示", MessageBoxButtons.OKCancel, MessageBoxIcon.Question);
                                    if (dr != DialogResult.OK)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "【3102】医保明细审核事中分析服务调用失败：", errMsg).ToString();
                                        return rtnResult;
                                    }
                                }
                            }
                            */
                            #endregion

                            Global.pat.RYorCY = "2";
                            Global.pat.admType = 2;
                            JObject joSettle = new JObject();                            
                            if (hBus.preSettlement("2303",out joSettle, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "结算信息展示", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                rtnResult = JsonHelper.setIrisReturnValue(0, "预结算成功", null).ToString();
                                return rtnResult;
                            }
                        }
                    case "Z4C"://住院预结算撤销
                        {
                            rtnResult = JsonHelper.setExceptionJson(-100, "该接口不支持预结算取消！", null).ToString();
                            return rtnResult;
                        }
                    case "Z5"://住院结算
                        {
                            //打开读卡窗口，操作员选择读卡类型后进行读卡器读卡，再进行1101获取参保信息
                            string patInfo = "";
                            if (hBus.readCard(out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "读卡失败！", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                patInfo = outParam;
                                //展示患者信息界面
                                if (hBus.showPatInfo(patInfo, out outParam) != 0)
                                {
                                    rtnResult = outParam;
                                    return rtnResult;
                                }
                                else
                                {
                                    if (hBus.setGlobalPatAfaterShowPatInfo(outParam, out errMsg) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "setGlobalPatAfaterShowPatInfo", errMsg).ToString();
                                        return rtnResult;
                                    }

                                    //校验HIS姓名与医保姓名是否一致
                                    if (hBus.checkName(Global.pat.name, out errMsg) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "校验HIS与医保姓名是否一致", errMsg).ToString();
                                        return rtnResult;
                                    }
                                }
                            }

                            #region【住院正式结算前调用社保卡验密】
                            if ((Global.pat.mdtrtcertType == "03") && (Global.pat.insuplc_admdvs.Substring(0, 2) == "62"))
                            {
                                if (CardRead_GS.VerifyPIN(out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "社保卡验密异常iVerifyPIN失败 ", outParam).ToString();
                                    return rtnResult;
                                }
                            }
                            #endregion

                            #region【住院预结算2303前调用3102医保明细审核事中服务】                            
                            //1.获取3102入参报文
                            if (hIS.GetInsuPatInfo("9", Global.pat, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "获取3102医保明细审核事中分析服务入参失败：", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                //2.调用医保3102明细审核事前分析服务
                                JObject joInput = new JObject();
                                joInput = JObject.Parse(outParam);
                                JObject jo3102Rtn = invoker.invokeCenterService("3102", JsonHelper.setCenterInpar("3102", joInput.ToString().Replace("\r\n", "")));
                                if (JsonHelper.parseCenterRtnValue(jo3102Rtn, out errMsg) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "【3102】医保明细审核事中分析服务调用失败：", errMsg).ToString();
                                    return rtnResult;
                                }
                                else
                                {
                                    JArray jaResult = JArray.Parse(JsonHelper.getDestValue(jo3102Rtn, "output.result"));
                                    if (jaResult.HasValues)
                                    {
                                        PreAndInProcessAnalysisForm paipaForm = new PreAndInProcessAnalysisForm(jo3102Rtn);
                                        if (paipaForm.ShowDialog() != DialogResult.OK)
                                        {
                                            errMsg = "事前事中审核不通过，操作员取消!";
                                            rtnResult = JsonHelper.setExceptionJson(-1, "【3102】医保明细审核事中分析服务调用失败：", errMsg).ToString();
                                            return rtnResult;
                                        }
                                    }
                                }
                            }
                            #endregion

                            Global.pat.admType = 2;
                            Global.pat.RYorCY = "2";
                            JObject joPreSetOutpar ;
                            if (hBus.preSettlement("2303",out joPreSetOutpar, out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "结算信息展示", outParam).ToString();
                                return rtnResult;
                            }
                            else
                            {
                                JObject joSettlement = JObject.Parse(JsonHelper.getDestValue(joPreSetOutpar, "Settlement"));

                                //正式结算
                                joSettlement.Add("data", joSettlement);
                                JObject jo2304Rtn = invoker.invokeCenterService("2304",JsonHelper.setCenterInpar("2304",joSettlement));
                                if (JsonHelper.parseCenterRtnValue(jo2304Rtn, out errMsg) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "结算失败", errMsg).ToString();
                                    cBus.cancleRegister("2405", out errMsg);
                                    return rtnResult;
                                }
                                else
                                {
                                    //返回给云医保平台结算信息
                                    if (mIS.saveSettlement(jo2304Rtn, out errMsg) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "结算成功，但云医保平台保存失败", errMsg).ToString();
                                        return rtnResult;
                                    }
                                    //返回给云医保平台结算明细信息
                                    if (mIS.saveSettlementDetail(jo2304Rtn, out errMsg) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "云医保平台保存结算明细失败", errMsg).ToString();
                                        Global.writeLog(rtnResult);
                                        MessageBox.Show(errMsg);
                                    }
                                    //返回给HIS
                                    JObject joSetlinfo = JObject.Parse(JsonHelper.getDestValue(jo2304Rtn, "output.setlinfo"));
                                    if (hIS.returnInpatSettlementInfo(joParam, joSetlinfo, out outParam) != 0)
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(-1, "返回结算信息给HIS", outParam).ToString();
                                        return rtnResult;
                                    }
                                    else
                                    {
                                        //返回给前端
                                        JObject joHisServieRtn = JObject.Parse(outParam);
                                        hBus.returnToFrontEndAfterSettlement(jo2304Rtn, joHisServieRtn, out outParam);
                                        rtnResult = JsonHelper.setIrisReturnValue(0, "结算成功", JObject.Parse(outParam)).ToString();
                                        return rtnResult;
                                    }
                                }
                            }
                        }
                    case "Z5C"://住院结算撤销
                        {
                            //查询结算表
                            string sqlStr = "SELECT * FROM  BS_MedInsuSettlement WHERE billType = 1 and Hospital_Dr=" + Global.inf.hospitalDr
                                          + " and Adm_Dr='" + Global.pat.adm_Dr + "'"
                                          + " and MdtrtID='" + Global.pat.mdtrtID + "'"
                                          + " Order By ID DESC ";

                            JObject joSql = new JObject();
                            joSql.Add("sqlStr", sqlStr);
                            JObject joSettlInfo = mIS.QuerySettlementInfo(joSql);
                            //if (JsonHelper.parseIrisRtnValue(joSettlInfo, out errMsg) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "查询结算信息失败！", errMsg).ToString();
                            //    return rtnResult;
                            //}

                            //MessageBox.Show(joSettlInfo.ToString());

                            Global.pat.insuplc_admdvs = JsonHelper.getDestValue(joSettlInfo, "result.data[0].insuplc_admdvs");

                            Global.pat.SettID_YBJSB = JsonHelper.getDestValue(joSettlInfo, "result.data[0].SettlementID");

                            if (Global.pat.settlID != Global.pat.SettID_YBJSB)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易", "通过09010059服务获取到的SettlementID<" + Global.pat.settlID + ">与DLL通过SQL语句" +
                                                                            joSql + ",获取到的SettlementID<" + Global.pat.SettID_YBJSB + ">不同,可能存在HIS单边账,请联系医保开发人员处理该笔结算记录！").ToString();
                                //return rtnResult;
                            }

                            Global.pat.settlID = Global.pat.SettID_YBJSB;

                            //取消中心结算信息
                            if (cBus.cancleSettlement("2305", out outParam) != 0)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-1, "取消中心结算信息失败！", outParam).ToString();

                                //查看是医保平台是否已经退费，如果是，则询问是否继续退费
                                string SqlStr = " SELECT * FROM  BS_MedInsuSettlement WHERE  ValidFlag = 0 AND BillType = -1 ";
                                SqlStr = SqlStr + " AND Hospital_Dr=" + Global.inf.hospitalDr + " AND Interface_Dr=" + Global.inf.interfaceDr;
                                SqlStr = SqlStr + " AND SettlementID ='" + Global.pat.settlID + "'";

                                JObject joSqlStr = new JObject();
                                joSqlStr.Add("sqlStr", SqlStr);

                                JObject joCancleSettlInfo = mIS.QuerySettlementInfo(joSqlStr);
                                JArray jaCancleSettlInfo = JArray.Parse(JsonHelper.getDestValue(joCancleSettlInfo, "result.data"));
                                if (jaCancleSettlInfo.Count == 1)
                                {
                                    //询问收款员是否继续进行HIS退费
                                    if (DialogResult.Yes == MessageBox.Show("中心提示：" + outParam, " 该费用在医保中心已成功退费但在HIS未成功退费，是否强制退HIS费用？ ", MessageBoxButtons.YesNo))
                                    {
                                        rtnResult = JsonHelper.setExceptionJson(0, "该费用在医保中心已成功退费但在HIS未成功退费，收款员选择强制退HIS费用！", outParam).ToString();
                                    }
                                }
                                else
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "取消中心结算(云医保平台未退费或未查询到退费记录)", outParam).ToString();
                                }

                                return rtnResult;
                            }
                            else
                            {
                                //退结算会返一个新的ID
                                string newSettleID = JsonHelper.getDestValue(JObject.Parse(outParam), "output.setlinfo.setl_id");
                                //取消平台结算信息
                                if (mIS.cancleSettlement(newSettleID, out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "中心结算取消成功，医保平台结算信息取消失败！", outParam).ToString();
                                    return rtnResult;
                                }







                                //中心取消传送
                                if (cBus.cancleFeeUpload("2302", out errMsg) != 0)
                                {
                                    //rtnResult = JsonHelper.setExceptionJson(-1, "取消中心费用", errMsg).ToString();
                                    //return rtnResult;
                                }
                                //云平台取消传送
                                if (mIS.deleteFee(out errMsg) != 0)
                                {
                                    //rtnResult = JsonHelper.setExceptionJson(-1, "删除医保平台费用", errMsg).ToString();
                                    //return rtnResult;
                                }







                                //取消HIS医保结算信息
                                if (hIS.cancleSettlementInfo(joParam, out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-1, "中心跟医保平台结算取消成功， 取消HIS结算信息失败！", outParam).ToString();
                                    return rtnResult;
                                }
                                //取消出院登记
                                if (cBus.cancleRegister("2405", out outParam) != 0)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(0, "中心，医保平台及HIS结算信息取消成功，取消出院登记失败！请手工取消出院登记！", outParam).ToString();
                                    return rtnResult;
                                }

                                rtnResult = JsonHelper.setIrisReturnValue(0, "取消结算成功", null).ToString();
                                return rtnResult;
                            }
                        }
                    default:
                        {
                            rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易", "传入的业务编码不对！").ToString();
                            return rtnResult;
                        }

                }
                return rtnResult;
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setExceptionJson(-1, "Settlement 交易", ex.Message).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("Settlement 出参：" + JsonHelper.Compress(rtnResult));
            }
        }

        //[STAThread]
        //public void print(JObject joInParam)
        //{
        //    //显示打印界面
        //    SettlementChecklist frmSettlList;
        //    string insuAdmObj = JsonHelper.getDestValue(joInParam, "insuAdmObj");
        //    if (insuAdmObj == "")
        //    {
        //        frmSettlList = new SettlementChecklist();
        //    }
        //    else
        //    {
        //        JObject joInsuAdmObj = JObject.Parse(insuAdmObj);
        //        frmSettlList = new SettlementChecklist(joInsuAdmObj);
        //    }
        //    if (frmSettlList.ShowDialog() == DialogResult.OK)
        //    {

        //    };
        //}
        //[STAThread]

        /// <summary>
        /// 辅助交易
        /// </summary>
        /// <param name="InParam"></param>
        /// <returns></returns>
        public string AgentFun(string InParam)
        {
            Global.writeLog("AgentFun 入参:" + JsonHelper.Compress(InParam));
            //设置返回值，错误信息
            int errCode;
            string errMsg, rtnResult = "", outParam;
            try
            {
                //解析入参
                if (parseInparam(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "", errMsg).ToString();
                    return rtnResult;
                }

                //BS架构调用方式问题，每次调用都需要重新初始化
                if (init(InParam, out outParam) != 0)
                {
                    rtnResult = outParam;
                    return rtnResult;
                }

                //获取通用目录
                string sTYML = mIS.GetCommonInterface_Dr(Global.inf.interfaceDr.ToString(), "");
                if (sTYML == "")
                    Global.inf.interfaceDr_TY = Global.inf.interfaceDr;
                else
                    Global.inf.interfaceDr_TY = int.Parse(sTYML);

                //获取pat
                //hBus.GetFeeHisInfo(businessType, joInParam, out Global.pat);
                switch (businessType)
                {
                    case "BasicData"://基础数据维护
                        {
                            BasicData bd = new BasicData();
                            if (bd.ShowDialog() != DialogResult.OK)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "", "已退出基础数据维护界面").ToString();
                                return rtnResult;
                            }
                            break;
                        }
                    case "Exception"://异常处理
                        {
                            //显示异常处理界面
                            HandleException frmEX = new HandleException();
                            if (frmEX.ShowDialog() != DialogResult.OK)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "", "已退出异常处理界面").ToString();
                                return rtnResult;
                            }
                            break;
                        }
                    case "CheckAndClearing"://对账清算
                        {
                            Clearing frmEX = new Clearing();
                            if (frmEX.ShowDialog() != DialogResult.OK)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "", "已退出对账清算界面").ToString();
                                return rtnResult;
                            }
                            break;
                        }
                    case "Print"://打印
                        {              
                            //显示打印界面
                            SettlementBillPrint frmSettlList;
                            string insuAdmObj = JsonHelper.getDestValue(joInParam, "insuAdmObj");

                            if (insuAdmObj == "") 
                            {
                                frmSettlList = new SettlementBillPrint();
                                if (frmSettlList.ShowDialog() != DialogResult.OK)
                                {
                                    rtnResult = JsonHelper.setExceptionJson(-100, "", "已退出打印界面").ToString();
                                    return rtnResult;
                                }
                            }
                            else
                            {
                                JObject joInsuAdmObj = JObject.Parse(insuAdmObj);
                                frmSettlList = new SettlementBillPrint(joInsuAdmObj);

                                string groupID = JsonHelper.getDestValue((JObject)Global.curEvt.jaSession[0], "groupID");
                                string userName = JsonHelper.getDestValue((JObject)Global.curEvt.jaSession[0], "userName");

                                DataTable dt = (DataTable)frmSettlList.dgvSettlRecord.DataSource;

                                int i = frmSettlList.dgvSettlRecord.CurrentRow.Index;                

                                string AdmID = dt.Rows[i]["AdmID"].ToString();
                                string PsnNo = dt.Rows[i]["PersonnelNO"].ToString();
                                string MdtrtID = dt.Rows[i]["MdtrtID"].ToString();
                                string SettlementID = dt.Rows[i]["SettlementID"].ToString();                                                     
                                Global.pat.adm_Dr = int.Parse(AdmID);

                                if (((groupID == "3") && (dt.Rows.Count > 0)) || 
                                     (userName == "朱振") || (userName == "朱鹏飞") ||(userName == "陈蒙") || 
                                     (userName == "张可宁") || (userName == "史绍兴") || (userName == "陈柏全") ||
                                     (userName == "李翔") || (userName == "王晓兵") || (userName == "史绍兴"))                                
                                {
                                    //frmSettlList.ShowDialog();
                                    frmSettlList.btnDesign_Click(null, null);
                                }
                                else
                                {
                                    JObject joRtnFee = frmSettlList.UpdateMedInsuUploadData(AdmID, PsnNo, MdtrtID, SettlementID);

                                    frmSettlList.btnPrint_Click(null, null);
                                }                                
                            }

                            return JsonHelper.setIrisReturnValue(0, "", null).ToString();
                            break;
                        }
                    case "Log"://日志
                        {
                            MessageBox.Show(businessType);
                            break;
                        }
                    case "RecordUpload"://上传记录
                        {
                            MessageBox.Show(businessType);
                            break;
                        }
                    case "HospitalRegister"://备案
                        {
                            ToRecordChoose Referral = new ToRecordChoose();              
                            if (Referral.ShowDialog() != DialogResult.OK)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "", "已退出备案信息界面").ToString();
                                return rtnResult;
                            }
                            break;
                        }
                    case "MedInsuQuery"://医保查询
                        {
                            MedInsuQuery MedQuery = new MedInsuQuery();
                            if (MedQuery.ShowDialog() != DialogResult.OK)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "", "已退出医保查询界面").ToString();
                                return rtnResult;
                            }
                            break;
                        }
                    case "PrescribeCirculation"://医保电子处方流转
                        {
                            //PrescriptionCirculation PresCir = new PrescriptionCirculation();
                            PrescriptionCirculation PresCir = new PrescriptionCirculation("");
                            if (PresCir.ShowDialog() != DialogResult.OK)
                            {
                                rtnResult = JsonHelper.setExceptionJson(-100, "", "已退出医保电子处方流转界面").ToString();
                                return rtnResult;
                            }
                            break;
                        }
                    default:
                        {
                            rtnResult = JsonHelper.setExceptionJson(-1, "AgentFun 交易", "传入的业务编码不对【"+businessType+"】").ToString();
                            return rtnResult;
                        }
                }
                return rtnResult;
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setExceptionJson(-1, "AgentFun 交易", ex.Message).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("AgentFun 出参：" + JsonHelper.Compress(rtnResult));
            }

        }

        public string Download(string InParam)
        {
            Global.writeLog("Download 入参:" + JsonHelper.Compress(InParam));
            //设置返回值，错误信息
            int errCode;
            string errMsg, rtnResult = "", outParam;

            try
            {
                //解析入参
                if (parseInparam(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "", errMsg).ToString();
                    return rtnResult;
                }

                //BS架构调用方式问题，每次调用都需要重新初始化
                if (init(InParam, out outParam) != 0)
                {
                    rtnResult = outParam;
                    return rtnResult;
                }

                dynamic joData = new JObject();

                joData.data = joParam["data"];
                //string code = (string)joInParam["code"];
                string funNO = (string)joParam["funNO"];
                switch (businessType)
                {

                    case "DirectoryDownload":
                        {
                            string downloadParam = JsonHelper.setCenterInpar(funNO, joData.ToString());
                            rtnResult = hBus.DownloadDirectory(funNO, downloadParam).ToString();
                            break;
                        }
                    case "DictionayDownload":
                        {
                            string downloadParam = JsonHelper.setCenterInpar(funNO, joData.ToString());
                            rtnResult = hBus.downDictionary(downloadParam);
                            break;
                        }
                }
                return rtnResult;

            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setExceptionJson(-100, "Download", ex.Message).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("Download 出参：" +  rtnResult);
            }


        }
        
        public string PlatformDirectConnect(string InParam)
        {            
            //设置返回值，错误信息
            int errCode;
            string errMsg, rtnResult = "", outParam;
            try
            {
                Global.writeLog("PlatformDirectConnect 入参:" + JsonHelper.Compress(InParam));
                //解析入参
                if (parseInparam(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "", errMsg).ToString();
                    return rtnResult;
                }

                Global.businessType = businessType;
                string funNO = JsonHelper.getDestValue(joInParam, "funNO");
                //BS架构调用方式问题，每次调用都需要重新初始化
                if (init(InParam, out outParam) != 0)
                {
                    rtnResult = outParam;
                    return rtnResult;
                }
                Global.pat.insuplc_admdvs = JsonHelper.getDestValue(joInParam, "insuplc_admdvs");
                JObject joRtn = invoker.invokeCenterService(funNO, JsonHelper.setCenterInpar(funNO, joParam));
                if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "平台直连错误", errMsg).ToString();
                    return rtnResult;
                }
                else
                {
                    rtnResult = JsonHelper.setIrisReturnValue(0, "", joRtn).ToString();
                    return rtnResult;
                }
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setExceptionJson(-1, "PlatformDirectConnect 交易", ex.Message).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("PlatformDirectConnect 出参：" + JsonHelper.Compress(rtnResult));
            }
        }


        /// <summary>
        /// 自助机
        /// </summary>
        /// <param name="InParam"></param>
        /// <returns></returns>
        public string SelfServiceMachine(string InParam)
        {
            Global.writeLog("SelfServiceMachine 入参：" + JsonHelper.Compress(InParam));
            //设置返回值，错误信息
            string errMsg, rtnResult = "", outParam;
            try
            {
                //解析入参
                if (parseInparam(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "parseInparam", errMsg).ToString();
                    return rtnResult;
                }
                //获取pat
                hBus.GetSelfServiceMachineInfo(businessType, joInParam, out Global.pat);
                //BS架构调用方式问题，每次调用都需要重新初始化
                if (init(InParam, out errMsg) != 0)
                //if (hBus.InitA(InParam, out errMsg) != 0)
                {
                    rtnResult = JsonHelper.setExceptionJson(-1, "InitA", errMsg).ToString(); ;
                    return rtnResult;
                }
                else
                {
                    //joInParam.Add("patInfo", errMsg);
                    Global.writeLog($"InitA初始化成功！");
                }


                switch (businessType)
                {
                    case "GetPatientInfo"://读取患者信息，该节点无需重定向
                        {
                            //重定向

                            Business.Core.SelfServiceMachine.PatientService patientService = new Business.Core.SelfServiceMachine.PatientService();
                            rtnResult = patientService.GetPatientInfo();
                            break;
                        }
                    case "OPReg"://门诊挂号
                        {
                            #region 老版
                            //CardReader_GS CardRead_GS = new CardReader_GS();
                            //Global.pat.admType = 1;
                            //string patInfo = "";
                            ////打开读卡窗口，操作员选择读卡类型后进行读卡器读卡，再进行1101获取参保信息
                            //if (hBus.readCard(out outParam) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-100, "读卡失败！", outParam).ToString();
                            //    return rtnResult;
                            //}
                            //else
                            //{
                            //    patInfo = outParam;
                            //    //展示患者信息界面
                            //    if (hBus.showPatInfo(patInfo, out outParam) != 0)
                            //    {
                            //        rtnResult = outParam;
                            //        return rtnResult;
                            //    }
                            //}
                            ////患者信息赋值给全局变量
                            //patInfo = outParam;

                            //if (hBus.setGlobalPatAfaterShowPatInfo(patInfo, out errMsg) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "setGlobalPatAfaterShowPatInfo", errMsg).ToString();
                            //    return rtnResult;
                            //}
                            ////校验HIS姓名与医保姓名是否一致
                            //if (hBus.checkName(Global.pat.name, out errMsg) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "校验HIS与医保姓名是否一致", errMsg).ToString();
                            //    return rtnResult;
                            //}

                            ////显示登记面板
                            //if (hBus.showOutPatRegisterForm(out outParam) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "显示登记面板", outParam).ToString();
                            //    return rtnResult;
                            //}
                            //JObject joReg = JObject.Parse(outParam);

                            ////医保挂号
                            //JObject jo2201Inpar = JObject.Parse(JsonHelper.getDestProperty(joReg, "data"));
                            //JObject jo2201Inpar_plain = JObject.Parse(JsonHelper.getDestProperty(joReg, "data"));
                            //jo2201Inpar = JObject.Parse(JsonHelper.setCenterInpar("2201", jo2201Inpar));
                            //jo2201Inpar_plain = JObject.Parse(JsonHelper.setCenterInpar_plain("2201", jo2201Inpar_plain));
                            ////此处先取到就诊信息上传的入参，只要挂号成功就保存到云HIS后台（保存后台需要用到2203入参）
                            //JObject jo2203Inpar = new JObject();
                            //JObject jo2203Inpar_plain = new JObject();
                            //jo2203Inpar.Add("mdtrtinfo", JObject.Parse(JsonHelper.getDestValue(joReg, "mdtrtinfo")));
                            //jo2203Inpar.Add("diseinfo", JArray.Parse(JsonHelper.getDestValue(joReg, "diseinfo")));
                            //JObject jo2201Rtn = invoker.invokeCenterService("2201", jo2201Inpar);
                            //if (JsonHelper.parseCenterRtnValue(jo2201Rtn, out errMsg) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "医保挂号", errMsg).ToString();
                            //    return rtnResult;
                            //}
                            //else
                            //{
                            //    Global.pat.mdtrtID = JsonHelper.getDestValue(jo2201Rtn, "output.data.mdtrt_id");
                            //    //插入患者本次就诊用的参保信息
                            //    if (hBus.insertPatCurInsuInfo(patInfo, out outParam) != 0)
                            //    {
                            //        if (DialogResult.Yes != MessageBox.Show(outParam, " 是否继续？ ", MessageBoxButtons.YesNo))
                            //        {
                            //            rtnResult = JsonHelper.setExceptionJson(-1, "插入患者本次就诊用的参保信息，请联系管理员！是否继续？", outParam).ToString();
                            //            return rtnResult;
                            //        }
                            //    }
                            //    jo2203Inpar["mdtrtinfo"]["mdtrt_id"] = Global.pat.mdtrtID;
                            //    jo2203Inpar_plain = JObject.Parse(JsonHelper.setCenterInpar_plain("2203", jo2203Inpar));
                            //    jo2203Inpar = JObject.Parse(JsonHelper.setCenterInpar("2203", jo2203Inpar));
                            //    //门诊登记信息，插入云医保平台
                            //    jo2201Rtn.Add("validflag", 1);
                            //    jo2201Rtn.Add("regstate", 1);
                            //    jo2201Rtn.Add("type", 3);
                            //    Global.writeLog(jo2201Inpar_plain.ToString());
                            //    if (mIS.saveOutpatRegisterInfo(jo2201Inpar_plain, jo2201Rtn, jo2203Inpar_plain, out errMsg) != 0)
                            //    {
                            //        rtnResult = JsonHelper.setExceptionJson(-1, "中心登记成功但医保平台保存失败，请联系管理员！", errMsg).ToString();
                            //        return rtnResult;
                            //    }
                            //}

                            ////门诊就诊信息上传                            
                            //JObject jo2203Rtn = invoker.invokeCenterService("2203", jo2203Inpar);
                            //if (JsonHelper.parseCenterRtnValue(jo2203Rtn, out errMsg) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "门诊就诊信息上传", errMsg).ToString();
                            //    return rtnResult;
                            //}

                            //#region【门诊就诊信息上传成功后调用3101事前服务】                            
                            ////1.获取3101入参报文
                            //if (Global.curEvt.ext.isOpenAnalysis)
                            //{
                            //    if (hIS.GetInsuPatInfo("1", Global.pat, out outParam) != 0)
                            //    {
                            //        rtnResult = JsonHelper.setExceptionJson(-1, "获取3101医保明细审核事前分析服务入参失败：", outParam).ToString();
                            //        return rtnResult;
                            //    }
                            //    else
                            //    {
                            //        //2.调用医保3101明细审核事前分析服务
                            //        JObject joInput = new JObject();
                            //        //joInput.Add("data", JObject.Parse(outParam));
                            //        joInput = JObject.Parse(outParam);

                            //        JObject jo3101Rtn = invoker.invokeCenterService("3101", JsonHelper.setCenterInpar("3101", joInput.ToString().Replace("\r\n", ""))); //.Replace(" ", "")
                            //        if (JsonHelper.parseCenterRtnValue(jo3101Rtn, out errMsg) != 0)
                            //        {
                            //            rtnResult = JsonHelper.setExceptionJson(-1, "【3101】医保明细审核事前分析服务调用失败：", errMsg).ToString();
                            //            return rtnResult;
                            //        }
                            //        else
                            //        {
                            //            JArray jaResult = JArray.Parse(JsonHelper.getDestValue(jo3101Rtn, "output.result"));
                            //            if (jaResult.HasValues)
                            //            {
                            //                PreAndInProcessAnalysisForm paipaForm = new PreAndInProcessAnalysisForm(jo3101Rtn);
                            //                if (paipaForm.ShowDialog() != DialogResult.OK)
                            //                {
                            //                    errMsg = "事前事中审核不通过，操作员取消!";
                            //                    rtnResult = JsonHelper.setExceptionJson(-1, "【3101】医保明细审核事前分析服务调用失败：", errMsg).ToString();
                            //                    return rtnResult;
                            //                }
                            //            }
                            //        }
                            //    }
                            //}

                            //#endregion

                            ////费用上传
                            //if (hBus.uploadFee("2204", 50, out outParam) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "费用上传", outParam).ToString();
                            //    return rtnResult;
                            //}

                            //#region【门诊预结算2206前调用3102医保明细审核事中服务】     

                            //if (Global.curEvt.ext.isOpenAnalysis)
                            //{
                            //    //1.获取3102入参报文
                            //    if (hIS.GetInsuPatInfo("2", Global.pat, out outParam) != 0)
                            //    {
                            //        rtnResult = JsonHelper.setExceptionJson(-1, "获取3102医保明细审核事中分析服务入参失败：", outParam).ToString();
                            //        return rtnResult;
                            //    }
                            //    else
                            //    {
                            //        //2.调用医保3102明细审核事前分析服务
                            //        JObject joInput = new JObject();
                            //        //joInput.Add("data", JObject.Parse(outParam));
                            //        joInput = JObject.Parse(outParam);

                            //        JObject jo3102Rtn = invoker.invokeCenterService("3102", JsonHelper.setCenterInpar("3102", joInput.ToString().Replace("\r\n", "")));
                            //        if (JsonHelper.parseCenterRtnValue(jo3102Rtn, out errMsg) != 0)
                            //        {
                            //            rtnResult = JsonHelper.setExceptionJson(-1, "【3102】医保明细审核事中分析服务调用失败：", errMsg).ToString();
                            //            return rtnResult;
                            //        }
                            //        else
                            //        {
                            //            JArray jaResult = JArray.Parse(JsonHelper.getDestValue(jo3102Rtn, "output.result"));
                            //            if (jaResult.HasValues)
                            //            {
                            //                PreAndInProcessAnalysisForm paipaForm = new PreAndInProcessAnalysisForm(jo3102Rtn);
                            //                if (paipaForm.ShowDialog() != DialogResult.OK)
                            //                {
                            //                    errMsg = "事前事中审核不通过，操作员取消!";
                            //                    rtnResult = JsonHelper.setExceptionJson(-1, "【3102】医保明细审核事中分析服务调用失败：", errMsg).ToString();
                            //                    return rtnResult;
                            //                }
                            //            }
                            //        }
                            //    }
                            //}

                            //#endregion

                            ////调用IRIS获取医保各项金额
                            //if (mIS.getSumFee(out outParam) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "获取医保费用各项汇总金额", outParam).ToString();
                            //    return rtnResult;
                            //}
                            //JObject joSumFee = JObject.Parse(outParam);
                            //JObject joSettlement = JObject.Parse(JsonHelper.getDestValue(joReg, "settlement"));
                            ////修改joSettlement的就诊ID ,总金额等
                            //joSettlement["mdtrt_id"] = Global.pat.mdtrtID;
                            //joSettlement["medfee_sumamt"] = JsonHelper.getDestValue(joSumFee, "data.Sumamt");

                            ////预结算2206
                            //if (hBus.preSettlement_OutPat(joSettlement, out outParam) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "结算信息展示", outParam).ToString();
                            //    return rtnResult;
                            //}

                            //#region【门诊正式结算前调用社保卡验密】
                            //if ((Global.pat.mdtrtcertType == "03") && (Global.pat.insuplc_admdvs.Substring(0, 2) == "62"))
                            //{
                            //    if (CardRead_GS.VerifyPIN(out outParam) != 0)
                            //    {
                            //        rtnResult = JsonHelper.setExceptionJson(-1, "社保卡验密异常iVerifyPIN失败 ", outParam).ToString();
                            //        return rtnResult;
                            //    }
                            //}
                            //#endregion

                            ////正式结算
                            //JObject joData = new JObject();
                            //joData.Add("data", joSettlement);
                            //JObject joRtn = invoker.invokeCenterService("2207", JsonHelper.setCenterInpar("2207", joData));
                            //if (JsonHelper.parseCenterRtnValue(joRtn, out errMsg) != 0)
                            //{
                            //    rtnResult = JsonHelper.setExceptionJson(-1, "结算失败", errMsg).ToString();
                            //    return rtnResult;
                            //}
                            //else
                            //{
                            //    //返回给云医保平台结算信息
                            //    if (mIS.saveSettlement(joRtn, out errMsg) != 0)
                            //    {
                            //        rtnResult = JsonHelper.setExceptionJson(-1, "结算成功，但云医保平台保存失败", errMsg).ToString();
                            //        return rtnResult;
                            //    }
                            //    //返回给云医保平台结算明细信息
                            //    if (mIS.saveSettlementDetail(joRtn, out errMsg) != 0)
                            //    {
                            //        rtnResult = JsonHelper.setExceptionJson(-1, "云医保平台保存结算明细失败", errMsg).ToString();

                            //        return rtnResult;
                            //    }

                            //    //返回给HIS
                            //    JObject joSetlinfo = JObject.Parse(JsonHelper.getDestValue(joRtn, "output.setlinfo"));
                            //    if (hIS.returnOutpatSettlementInfo(joSettlement, joSetlinfo, out outParam) != 0)
                            //    {
                            //        rtnResult = JsonHelper.setExceptionJson(-1, "返回结算信息给HIS", outParam).ToString();
                            //        return rtnResult;
                            //    }
                            //    else
                            //    {
                            //        JObject joHisServieRtn = JObject.Parse(outParam);
                            //        hBus.returnToFrontEndAfterSettlement(joRtn, joHisServieRtn, out outParam);
                            //        rtnResult = JsonHelper.setIrisReturnValue(0, "结算成功", JObject.Parse(outParam)).ToString();
                            //        return rtnResult;
                            //    }
                            //}
                            #endregion

                            #region 链条式任务调度者
                            OPRegService service = new OPRegService();
                            rtnResult = service.Charge(operationType, joInParam);
                            break;
                            #endregion
                        }
                    case "OPSettl"://门诊结算
                        {
                            OPSettlementService service = new OPSettlementService();
                            rtnResult = service.Charge(operationType, joInParam);
                            break;
                        }
                    case "IPInReg"://入院登记
                        {
                            IPAdmRegService service = new IPAdmRegService();
                            rtnResult = service.Register(operationType, joInParam);
                            break;
                        }
                    case "IPInRegCancel"://取消入院登记
                        {
                            IPAdmRegService service = new IPAdmRegService();
                            rtnResult = service.CancelRegister(operationType, joInParam);
                            break;
                        }
                    case "IPOutReg"://出院登记
                        {
                            break;
                        }
                    case "IPUpoload"://住院费用上传
                        {
                            break;
                        }
                    case "IPPreSettl"://住院预计结算
                        {
                            break;
                        }
                    case "IPSettl"://住院结算
                        {
                            IPSettlementService service = new IPSettlementService();
                            rtnResult = service.Charge(joInParam);
                            return rtnResult;
                        }
                    case "DischargeAudit"://费用核查
                        {
                            DischargeAuditService service = new DischargeAuditService();
                            rtnResult = service.Audit(joInParam);
                            return rtnResult;
                        }
                    default:
                        {
                            rtnResult = JsonHelper.setExceptionJson(-1, "SelfServiceMachine 交易", "传入的业务编码不对！").ToString();
                            return rtnResult;
                        }

                }
                return rtnResult;
            }
            catch (Exception ex)
            {
                rtnResult = JsonHelper.setExceptionJson(-1, "SelfServiceMachine 交易", ex.Message).ToString();
                return rtnResult;
            }
            finally
            {
                Global.writeLog("SelfServiceMachine 出参：" + JsonHelper.Compress(rtnResult));
            }
        }

    }


}
